:code:`agox plot`
==========

.. note:: 

   The most up to date help for :code:`agox plot` is available through `agox plot --help`.

Plots structures from either a database or trajectory file.

.. code-block:: console

    agox plot <file>

Arrow keys can be used to cycle through structures. With the :code:`-a` flag structures are shown in the ASE gui.
